"""
Copyright ©2018 Skylark Drones Private Limited, All Rights Reserved

Bringing Leaflet maps to PyQt.
"""

__author__ = 'Samarth Hattangady <samarth@skylarkdrones.com>'
__version__ = '0.2.1'

from .mapwidget import MapWidget
from .leaflet import L
